package cn.sh.stc.sict.cloud.auth.handler;

import cn.sh.stc.sict.cloud.common.core.constant.SecurityConstants;
import cn.sh.stc.sict.cloud.common.security.handler.AuthenticationSuccessHandler;
import cn.sh.stc.sict.cloud.common.security.util.SysLogUtils;
import cn.sh.stc.sict.cloud.upms.feign.RemoteLogService;
import cn.sh.stc.sict.cloud.upms.model.SysLog;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Async;
import org.springframework.security.core.Authentication;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * 登录成功日志记录
 */
@Slf4j
@Component
@AllArgsConstructor
public class SictAuthenticationSuccessLogEventHandler implements AuthenticationSuccessHandler {

    private final RemoteLogService remoteLogService;

    /**
     * 处理登录成功方法
     * <p>
     * 获取到登录的authentication 对象
     *
     * @param authentication 登录对象
     * @param request        请求
     * @param response       返回
     */
    @Async
    @Override
    public void handle(Authentication authentication, HttpServletRequest request, HttpServletResponse response) {
        String username = authentication.getName();
        SysLog sysLog = SysLogUtils.getSysLog(request, username);
        sysLog.setTitle(username + "用户登录");
        sysLog.setParams(username);
        remoteLogService.saveLog(sysLog, SecurityConstants.FROM_IN);
        log.info("用户：{} 登录成功", username);
    }

}
